@@ -47,7 +47,7 @@ DEALINGS IN THE SOFTWARE.
 
 extern "C"
 {
-	KDE_EXPORT TQWidget* allocate_tdestyle_config(TQWidget* parent)
+	TDE_EXPORT TQWidget* allocate_tdestyle_config(TQWidget* parent)
 	{
 		TDEGlobal::locale()->insertCatalogue("tdestyle_lipstik_config");
 		return new LipstikStyleConfig(parent);
